Returns location and period-of-record information for all stations available across registered data sources. Data sources that do not publish station metadata are skipped with a warning.
Arguments
- source
Optional single character string naming the data source to query directly. When
NULL(default) all registered data sources are queried. Seehc_list_sources()for available names.